package test.cn.unitid.realidentity.openapi.sdk.test;

import cn.unitid.realidentity.sdk.ApiClient;
import cn.unitid.realidentity.sdk.ApiException;
import cn.unitid.realidentity.sdk.DefaultApiClient;
import cn.unitid.realidentity.sdk.FileItem;
import cn.unitid.realidentity.sdk.internal.util.WebUtils;
import cn.unitid.realidentity.sdk.request.CertificateIssueEnterpriseEV3Request;
import cn.unitid.realidentity.sdk.request.FsUploadPolicyRequest;
import cn.unitid.realidentity.sdk.response.CertificateIssueEnterpriseEV3Response;
import cn.unitid.realidentity.sdk.response.FsUploadPolicyResponse;
import cn.unitid.realidentity.sdk.utils.PKCS10Utils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * 企业证书EV3（视频）
 *
 * @author 万红云
 * @date 2020-03-25 19:22
 */
public class CertificateIissueEnterpriseEV3 {

    public static void main(String[] args) {

        try {
            //提供的url
            String url = "http://iv.unitid.cn/api/router/rest";
            //您的appKey
            String appkey = "XXX";
            //您的appSecret
            String secretKey = "XXX";

            //1.原客户端
            ApiClient apiClient = new DefaultApiClient(url, appkey, secretKey);
            //2.调用出错，自动重试客户端
            //AutoRetryApiClient apiClient = new AutoRetryApiClient(url, appkey, secretKey);

            CertificateIssueEnterpriseEV3Request req = new CertificateIssueEnterpriseEV3Request();
            req.setIdcard("XXX");
            req.setRealname("XXX");
            req.setP10(PKCS10Utils.generateP10("CN=" + req.getRealname() + ",2.5.4.20=" + req.getIdcard() + ",OU=YZT,C=CN"));
            //1.以base64:开头，图片转换成base64位字符串
            //String video = Base64.encodeBase64String(FileUtils.readFileToByteArray(new File("D:\\workspace\\realid\\real-identity-openapi-java-sdk\\src\\test\\resources\\data\\yrj.mp4")));
            //req.setVideoDataBase64(video);
            //2.fs: 开头
            req.setVideoDataFs(uploadFile(apiClient, "liveness_video", "D:\\XXX.mp4"));

            CertificateIssueEnterpriseEV3Response res = apiClient.execute(req);
            if (res.getData().getIncorrect() == 100) {
                //后续业务处理
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 上传文件
     */
    private static String uploadFile(ApiClient apiClient, String bizType, String path) throws ApiException, IOException {

        FsUploadPolicyRequest fsUploadPolicyRequest = new FsUploadPolicyRequest();
        fsUploadPolicyRequest.setBizType(bizType);
        //获取文件上传权限
        FsUploadPolicyResponse fsResponse = apiClient.execute(fsUploadPolicyRequest);
        //获取权限识别
        if (null == fsResponse.getData()) {
            throw new ApiException();
        }
        //上传文件示例
        Map<String, String> params = new HashMap<String, String>(5);
        params.put("token", fsResponse.getData().getToken());
        if (fsResponse.getData().getObjectKey().endsWith("/")) {
            params.put("key", fsResponse.getData().getObjectKey() + "${filename}");
        } else {
            params.put("key", fsResponse.getData().getObjectKey());
        }
        //需要上传的文件
        Map<String, FileItem> fileParams = new HashMap<String, FileItem>(5);
        fileParams.put("file", new FileItem(new File(path)));
        //上传
        String uploadUrl = fsResponse.getData().getUploadUrl();
        String json = WebUtils.doPost(uploadUrl, params, fileParams, 30000, 30000);
        JSONObject jsonObject = JSON.parseObject(json);

        return jsonObject.getString("bucket") + ":" + jsonObject.getString("objectKey");
    }

}
