package test.cn.unitid.realidentity.openapi.sdk.test;

import cn.unitid.realidentity.sdk.ApiClient;
import cn.unitid.realidentity.sdk.ApiException;
import cn.unitid.realidentity.sdk.DefaultApiClient;
import cn.unitid.realidentity.sdk.FileItem;
import cn.unitid.realidentity.sdk.internal.util.FileContentTypeUtils;
import cn.unitid.realidentity.sdk.internal.util.WebUtils;
import cn.unitid.realidentity.sdk.request.FsUploadPolicyRequest;
import cn.unitid.realidentity.sdk.request.OcrRecognitionRequest;
import cn.unitid.realidentity.sdk.response.FsUploadPolicyResponse;
import cn.unitid.realidentity.sdk.response.OcrRecognitionResponse;
import cn.unitid.realidentity.sdk.utils.Sm4Utils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.io.FileUtils;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * 文件上传
 */
public class FsUpload {

    public static void main(String[] args) throws IOException {

        //提供的url
        String url = "http://iv.unitid.cn/api/router/rest";
        //您的appKey
        String appkey = "XXX";
        //您的appSecret
        String secretKey = "XXX";
        //业务类型
        String bizType = "XXX";

        //1.原客户端
        ApiClient apiClient = new DefaultApiClient(url, appkey, secretKey);
        //2.调用出错，自动重试客户端
        //AutoRetryApiClient apiClient = new AutoRetryApiClient(url, appkey, secretKey);
        FsUploadPolicyRequest req = new FsUploadPolicyRequest();
        req.setBizType(bizType);
        try {

            //获取文件上传权限
            FsUploadPolicyResponse fsResponse = apiClient.execute(req);
            //获取权限失败
            if (null == fsResponse.getData()) {
                throw new ApiException();
            }


            //获取权限成功，上传文件示例
            Map<String, String> params = new HashMap<String, String>(5);
            params.put("token", fsResponse.getData().getToken());
            //以/结尾，可以上传多文件
            if (fsResponse.getData().getObjectKey().endsWith("/")) {
                params.put("key", fsResponse.getData().getObjectKey() + "${filename}");
            } else {
                //不以/结尾只能上传单文件
                params.put("key", fsResponse.getData().getObjectKey());
            }
            //需要上传的文件
            Map<String, FileItem> fileParams = new HashMap<String, FileItem>(5);
//            //base64字符串
//            String baset64String = FileUtils.readFileToString(new File("C:\\workspace\\real-identity-openapi-java-sdk\\src\\test\\resources\\data\\cwb.txt"), "utf-8");
//            fileParams.put("file", new FileItem("uu.jpg", Base64.decodeBase64(baset64String)));
            fileParams.put("file", new FileItem(new File("C:\\workspace\\real-identity-openapi-java-sdk\\src\\test\\resources\\data\\uu.jpg")));

//            // 当公共参数encMethod=SM4时,上传的文件也要进行加密
//            // 获取文件流
//            File file = new File("C:\\workspace\\real-identity-openapi-java-sdk\\src\\test\\resources\\data\\uu.jpg");
//            byte[] content = FileUtils.readFileToByteArray(file);
//            // 对文件进行加密
//            byte[] encryptContent = Sm4Utils.encrypt(content, DefaultApiClient.encPassword);
//            String fileName = file.getName();
//            fileParams.put("file", new FileItem(fileName, encryptContent, FileContentTypeUtils.mimeTypeByFilename(fileName)));

            //上传
            String json = WebUtils.doPost(fsResponse.getData().getUploadUrl(), params, fileParams, 5000, 30000);
            JSONObject jsonObject = JSON.parseObject(json);
            //上传失败
            if (null == jsonObject.getString("objectKey")) {
                throw new ApiException();
            }


            //上传成功，后续业务处理 如图片OCR识别支持fs路径,
            OcrRecognitionRequest ocrReq = new OcrRecognitionRequest();
            ocrReq.setImageType("IDCARD");
            String imgFs = jsonObject.getString("bucket") + ":" + jsonObject.getString("objectKey");
            ocrReq.setImageFs(imgFs);
            OcrRecognitionResponse response = apiClient.execute(ocrReq);
        } catch (ApiException e) {
            e.printStackTrace();
        }
    }

}
