package test.cn.unitid.realidentity.openapi.sdk.test;

import cn.unitid.realidentity.sdk.internal.util.ImageUtils;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.io.FileUtils;
import org.junit.Test;

import java.io.File;
import java.io.IOException;

/**
 * 图片处理
 */
public class ImageHandle {

    /**
     * 获取图片Exif方向 （原始图片，即没有经过压缩旋转裁剪等操作）
     *
     * @throws IOException
     */
    @Test
    public void test_getExifOrientation() throws IOException {
        //读取图片
        byte[] bytes = FileUtils.readFileToByteArray(new File("C:\\workspace\\real-identity-openapi-java-sdk\\src\\test\\resources\\data\\ll.JPG"));
        //获取拍照时旋转方向
        int angel = ImageUtils.getExifOrientation(bytes);
        System.out.println(angel);
    }

    /**
     * 图片压缩不超过指定大小
     *
     * @throws IOException
     */
    @Test
    public void test_imageCompress() throws IOException {
        //读取图片
        byte[] bytes = FileUtils.readFileToByteArray(new File("C:\\workspace\\real-identity-openapi-java-sdk\\src\\test\\resources\\data\\ll.JPG"));
        //获取图片类型
        String formatName = ImageUtils.getTypeByStream(bytes).split(",")[0];
        //图片压缩100KB以内，转JPEG格式
        byte[] res = ImageUtils.imageCompress(bytes, 1024 * 100, formatName);
        //转换成base64字符串
        String base64String = Base64.encodeBase64String(res);
        System.out.println(base64String);
    }

    /**
     * 图片裁剪
     *
     * @throws IOException
     */
    @Test
    public void test_imageCut() throws IOException {
        //读取图片
        byte[] bytes = FileUtils.readFileToByteArray(new File("C:\\workspace\\real-identity-openapi-java-sdk\\src\\test\\resources\\data\\ll.JPG"));
        //按指定坐标裁剪
        byte[] res = ImageUtils.imageCut(bytes, 200, 300, 400, 400, 200, 200, "JPEG");
        //转换成base64字符串
        String base64String = Base64.encodeBase64String(res);
        System.out.println(base64String);
    }


    /**
     * 图片旋转压缩，按照大小等比例压缩
     *
     * @throws IOException
     */
    @Test
    public void test_imageRotateAndCompress() throws IOException {
        //读取图片
        byte[] bytes = FileUtils.readFileToByteArray(new File("C:\\workspace\\real-identity-openapi-java-sdk\\src\\test\\resources\\data\\ll.JPG"));
        //图片旋转压缩，转JPEG格式
        byte[] res = ImageUtils.imageRotateAndCompress(bytes, "JPEG");
        //转换成base64字符串
        String base64String = Base64.encodeBase64String(res);
        System.out.println(base64String);
    }
}
