package test.cn.unitid.realidentity.openapi.sdk.test;

import cn.unitid.realidentity.sdk.ApiClient;
import cn.unitid.realidentity.sdk.ApiException;
import cn.unitid.realidentity.sdk.DefaultApiClient;
import cn.unitid.realidentity.sdk.FileItem;
import cn.unitid.realidentity.sdk.constant.EncryptMethod;
import cn.unitid.realidentity.sdk.internal.util.FileContentTypeUtils;
import cn.unitid.realidentity.sdk.internal.util.WebUtils;
import cn.unitid.realidentity.sdk.request.FsUploadPolicyRequest;
import cn.unitid.realidentity.sdk.request.OcrRecognitionRequest;
import cn.unitid.realidentity.sdk.response.FsUploadPolicyResponse;
import cn.unitid.realidentity.sdk.response.OcrRecognitionResponse;
import cn.unitid.realidentity.sdk.utils.SecretGenerateUtils;
import cn.unitid.realidentity.sdk.utils.Sm4Utils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.io.FileUtils;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * 图片OCR识别
 */
public class OcrRecognition {

    public static void main(String[] args) throws IOException {

        try {
            //提供的url
            String url = "http://iv.unitid.cn/api/router/rest";
            //您的appKey
            String appkey = "XXX";
            //您的appSecret
            String secretKey = "XXX";

            //1.原客户端
            ApiClient apiClient = new DefaultApiClient(url, appkey, secretKey);
            //2.调用出错，自动重试客户端
            //AutoRetryApiClient apiClient = new AutoRetryApiClient(url, appkey, secretKey);
            OcrRecognitionRequest req = new OcrRecognitionRequest();
            //选填
            req.setFields("face");
            req.setImageType("IDCARD");

//        //1.以base64:开头，图片转换成base64位字符串
//        String img = Base64.encodeBase64String(FileUtils.readFileToByteArray(new File("C:/Users/admin/Pictures/Saved Pictures/jj.jpg")));
//        req.setImagBase64(img);

            //2.fs:开头，需要调用我们提供的上传接口,获取bucket，和objectKey，格式为：fs:+bucket:+objectKey
            String bucket = "XXX";
            String objectKey = "XXX";
            String imgData = bucket + ":" + objectKey;
            req.setImageFs(imgData);

            // 配置此参数时,会对请求参数中的image和响应结果中info属性做加密
//            req.setEncMethod(EncryptMethod.SM4);
//            // 当设置encMethod后，fs上传文件也需要加密
//            byte[] encPassword = SecretGenerateUtils.getSecretKey(appkey, secretKey);
//            String fsKey = uploadFile(apiClient, "ocr", "C:/Users/admin/Pictures/Saved Pictures/jj.jpg", encPassword);
//            req.setImageFs(fsKey);

            // 设置 EncMethod 属性后,SDK会info做自动解密,您无需处理
            OcrRecognitionResponse response = apiClient.execute(req);
            //后续业务处理
        } catch (ApiException e) {
            e.printStackTrace();
        }
    }

    /**
     * 上传文件
     *
     * @param apiClient   客户端
     * @param bizType     文件上传业务类型
     * @param path        需要上传的文件路径
     * @param encPassword 文件加密密码,不为null对文件进行加密
     * @return bucket:objectKey
     */
    private static String uploadFile(ApiClient apiClient, String bizType, String path, byte[] encPassword) throws ApiException, IOException {

        FsUploadPolicyRequest fsUploadPolicyRequest = new FsUploadPolicyRequest();
        fsUploadPolicyRequest.setBizType(bizType);
        //获取文件上传权限
        FsUploadPolicyResponse fsResponse = apiClient.execute(fsUploadPolicyRequest);
        //获取权限识别
        if (null == fsResponse.getData()) {
            throw new ApiException();
        }
        //上传文件示例
        Map<String, String> params = new HashMap<String, String>(5);
        params.put("token", fsResponse.getData().getToken());
        if (fsResponse.getData().getObjectKey().endsWith("/")) {
            params.put("key", fsResponse.getData().getObjectKey() + "${filename}");
        } else {
            params.put("key", fsResponse.getData().getObjectKey());
        }
        //需要上传的文件
        Map<String, FileItem> fileParams = new HashMap<String, FileItem>(5);

        File file = new File(path);
        if (encPassword != null) {
            byte[] bytes = FileUtils.readFileToByteArray(file);
            byte[] encryptContent = Sm4Utils.encrypt(bytes, encPassword);
            String fileName = file.getName();
            FileItem fileItem = new FileItem(fileName, encryptContent, FileContentTypeUtils.mimeTypeByFilename(fileName));
            fileParams.put("file", fileItem);
        } else {
            fileParams.put("file", new FileItem(file));
        }

        //上传
        String uploadUrl = fsResponse.getData().getUploadUrl();
        String json = WebUtils.doPost(uploadUrl, params, fileParams, 30000, 30000);
        JSONObject jsonObject = JSON.parseObject(json);

        return jsonObject.getString("bucket") + ":" + jsonObject.getString("objectKey");
    }
}